#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 OneTuple
version:              0.4.3
visibility:           public
id:                   OneTuple-0.4.3-LHDdl4VWBDgLOgfmdTjsbm
key:                  OneTuple-0.4.3-LHDdl4VWBDgLOgfmdTjsbm
license:              BSD-3-Clause
copyright:            (c) John Dorsey 2008
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, John Dorsey <haskell@colquitt.org>

author:               John Dorsey <haskell@colquitt.org>
stability:            experimental
synopsis:             Singleton Tuple
description:
    This package is a compatibility package for a singleton data type

    > data Solo a = MkSolo a

    Note: it'\''s not a @newtype@

    @Solo@ is available in @base-4.16@ (GHC-9.2).

category:             Data
abi:                  c8b162f1f4209506de0677322d4a23d6
exposed:              True
exposed-modules:
    Data.Tuple.OneTuple Data.Tuple.Solo Data.Tuple.Solo.TH

import-dirs:          /usr/lib/ghc-9.6.6/site-local/OneTuple-0.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/OneTuple-0.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/OneTuple-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-onetuple
hs-libraries:         HSOneTuple-0.4.3-LHDdl4VWBDgLOgfmdTjsbm
depends:
    base-4.18.2.1 ghc-prim-0.10.0 template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-onetuple/html/OneTuple.haddock
haddock-html:         /usr/share/doc/haskell-onetuple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

